@@ -1,9 +1,7 @@
-#' @name strpart
-#' @keywords extract part string
-#' @author Sven E. Templer (\email{sven.templer@@gmail.com})
-#' @title Split String and Return Part
-#' @description
-#' Split character strings by split identifier and return certain part.
+#' Split String and Return Part
+#' 
+#' Return the nth part of a splitted string.
+#' 
 #' @param x Character vector.
 #' @param split Regular expression splitting strings.
 #' @param n Number of part to extract.
@@ -14,17 +12,22 @@
 #' @seealso
 #' \link{strsplit}
 #' @examples
+#' #
+#' 
 #' strpart(c("abc","abcb","abc"), "", 4)
+#' strpart(c("abc","abcb","abc"), "", 4, roll=TRUE)
+#' 
+#' #
+#' @name strpart
+#' @keywords extract part string
+#' @author Sven E. Templer (\email{sven.templer@@gmail.com})
 
 #' @export strpart
 strpart <- function (x, split, n, ..., roll = F) {
   x <- strsplit(x, split, ...)
-  if (roll) {
-    x <- do.call(rbind, x)
-    if (n > ncol(x)) n <- ncol(x)
-    x <- x[,n]
-  } else {
+  if (roll)
+    x <- unlist(lapply(x, function (y) tail(y, 1)))
+  else
     x <- unlist(lapply(x, function (y) y[n]))
-  }
   return(x)
 }
